@@ -88,18 +88,8 @@ class BaseTestSuite(object):
         s = dumps(self.__dict__)
         return s
 
-    def build_suite(self, tests: [object]) -> None:
-
-        if not tests:
-            raise ValueError("tests cannot be None or empty...")
-
-        loader = TestLoader()
-        suites = []
-
-        for testCase in tests:
-            suite = loader.loadTestsFromTestCase(testCase)
-            suites.append(suite)
-        
-        self.__testSuite = TestSuite(suites)
+    def dump_events(self):
+        for event in self.CustomEvents:
+            print(str(event))
 
     #endregion
