@@ -6,7 +6,7 @@ from pyspark.sql.session import SparkSession
 class FactTestSuite(BaseTestSuite):
 
     def __init__(self, sparkSession: SparkSession, databaseName: str, tableName: str, linkedDimensions: [(str, str)], excludeFromAggregation: [str] = []):
-        super(TestSuiteFact, self).__init__(sparkSession, databaseName, tableName)
+        super(FactTestSuite, self).__init__(sparkSession, databaseName, tableName)
         self.__linkedDimensions = linkedDimensions
         self.__excludeFromAggregations = excludeFromAggregations
 
