@@ -5,7 +5,7 @@ from pyspark.sql.session import SparkSession
 class StagingTestSuite(BaseTestSuite):
 
     def __init__(self, sparkSession: SparkSession, databaseName: str, tableName: str) -> None:
-        super(TestSuiteStaging, self).__init__(sparkSession, databaseName, tableName)
+        super(StagingTestSuite, self).__init__(sparkSession, databaseName, tableName)
 
     def queue_tests(self) -> None:
         commonTestCase = CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents)
