@@ -19,7 +19,17 @@ class TestEvent(object):
     #region Overloads
     
     def __str__(self) -> str:
-        s = dumps(self.__dict__)
+
+        d = {}
+
+        d["test_name"] = self.TestName
+        d["notes"] = self.Notes
+        d["start"] = str(self.Start)
+        d["end"] = str(self.End)
+        d["duration"] = str(self.EventDurationSeconds())
+
+        s = dumps(d)
+
         return s
     
     #endregion
